..
    Developer note: the files in the generated folder are generated by the file
    `sphinx_dd_extension/autodoc.py`.

.. _`identifier reference`:

Identifier reference
====================

.. toctree::
    :name: dd-reference-toc-identifiers
    :glob:
    :maxdepth: 1

    generated/identifier/*
